/* testing TestRGF.java, Rony G. Flatscher, 2001-04-21

   purpose: this Rexx program demonstrates the usage of the Java class "TestRGF" and
            demonstrates the usage of the BSF-interface, especially getting and setting
            values of fields

   invoke:  enter the following command to inoke the Rexx program "UseTestRGF.rex":

                  "java com.ibm.bsf.Main -lang rexx -in UseTestRGF.rex"
            or
                  "java com.ibm.bsf.Main -in UseTestRGF.rex"

            if extension "rex" is defined in the text file "\com\ibm\bsf\Languages.properties",
            which allows for determining the needed engine by looking at the file extension
*/

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."


tr1 = "tr1"
type = "TestRGF"

say "Registering bean ..."
call bsf "registerBean", tr1, type

say "invoke toString() ..."
say left("", 79, "-")
say bsf("invoke", tr1, "toString")
say left("", 79, "-")

say "This came from Rexx."
say

say "invoke dump() ..."
say left("", 79, "-")
call bsf "invoke", tr1, "dump"
say left("", 79, "-")
say "This came from Java."
say

if1 = bsf( "invoke", tr1, "getInstField1")
say "if1="if1

sf1 = bsf( "invoke", tr1, "getStatField1")
say "sf1="sf1

say
say "Now invoking the class' access methods, changing thereby the field values..."
call bsf "invoke", tr1, "setStatField1", "I", sf1*1000
call bsf "invoke", tr1, "setInstField1", "I", if1*1000

say
say "Now invoking the 'dump' method of the class:"
say left("", 79, "-")
call bsf "invoke", tr1, "dump"
say left("", 79, "-")
say "This came from Java."

say
say "Now reading public fields *directly* with 'getFieldValue':"
say
say "statField1 [" || bsf('getFieldValue', tr1, 'statField1') || "] (a public static field)"
say "instField1 [" || bsf('getFieldValue', tr1, 'instField1') || "] (a public instance field)"
say left("", 40, "=")

say
say "instField2 [" || bsf('getFieldValue', tr1, 'instField2') || "] (a public instance field)"
say "instField3 [" || bsf('getFieldValue', tr1, 'instField3') || "] (a public instance field)"
say left("", 40, "=")
say

say left("", 40, "=")
say "Now setting public fields *directly* with 'setFieldValue' ..."
say
say "...new value for instField1: [" || bsf('setFieldValue', tr1, 'instField1', 'i', 1111) || "] (a public instance field)"
say "   get value for instField1: [" || bsf('getFieldValue', tr1, 'instField1') || "]"
say
say "...new value for instField2: [" || bsf('setFieldValue', tr1, 'instField2', 'i', 2222) || "] (a public instance field)"
say "   get value for instField2: [" || bsf('getFieldValue', tr1, 'instField2') || "]"
say
say "...new value for statField1: [" || bsf('setFieldValue', tr1, 'statField1', 'i', 9876) || "] (a public static field)"
say "   get value for statField1: [" || bsf('getFieldValue', tr1, 'statField1') || "]"
say left("", 40, "=")
say
say "now using the newly developed function for public static fields: 'getStaticalue'"
say
say "the public static field named 'statField1' has the value:" "[" || bsf('getStaticValue', "TestRGF", "statField1") || "]"

say
PARSE VERSION info
say "Using the following Rexx interpreter:" info

